@@ -7,17 +7,29 @@ test_that("missing, non-character or empty labels are rejected", {
 })
 
 test_that("utility values and distributions are supported", {
+  # invalid type
   expect_error(LeafNode$new("QALY", "ill"), class="invalid_utility")
+  # valid type, out of range
   expect_error(LeafNode$new("QALY", 2), class="invalid_utility")
+  # check that utility is returned
   t1 <- LeafNode$new("QALY", 0.5)
   expect_intol(t1$utility(), 0.5, 0.01)
+  mv <- t1$modvars()
+  expect_length(mv, 0)
+  # check that ModVars are supported
   u <- ConstModVar$new("poorly", "U", 0.25)
-  t1 <- LeafNode$new("QALY", utility=u)
+  t1 <- LeafNode$new("QALY", utility = u)
   expect_intol(t1$utility(), 0.25, 0.01)
   um <- ExprModVar$new("depressed", "U", rlang::quo(0.9*u))
   t1 <- LeafNode$new("QALY", utility=um)
   mv <- t1$modvars()
   expect_length(mv,2)
+  # check that using ModVar permits utilities > 1 (e.g. maternity)
+  umat <- ConstModVar$new("Pregnant", "U", 2.0)
+  expect_silent(
+    t1 <- LeafNode$new("QALY", utility = umat)
+  )
+  expect_intol(t1$utility(), 2, 0.01)
 })
 
 test_that("intervals are supported", {
