@@ -16,10 +16,13 @@ test_that("invalid annual costs are rejected", {
 })
 
 test_that("invalid utilities are rejected", {
-  expect_error(MarkovState$new(name="Futile", utility=list(42)),
-               class="invalid_utility")
-  expect_error(MarkovState$new(name="Futile", utility=2),
-               class="utility_out_of_range")
+  expect_error(
+    MarkovState$new(name = "Futile", utility = list(42)),
+    class = "invalid_utility"
+  )
+  expect_error(
+    MarkovState$new(name = "Futile", utility = 2),
+    class = "invalid_utility")
 })
 
 # tests of label, cost and utility
@@ -41,14 +44,14 @@ test_that("utilties are set and got", {
 # tests of costs and utilities that are ModVars
 test_that("state cost and utility ModVars are recognised", {
   # create model variables
-  c.dis <- GammaModVar$new("Cost", "GBP", shape=10000, scale=1/10)
-  u.dis <- BetaModVar$new("Utility", "U", alpha=10, beta=10) 
+  c.dis <- GammaModVar$new("Cost", "GBP", shape = 10000, scale = 1/10)
+  u.dis <- BetaModVar$new("Utility", "U", alpha = 10, beta = 10) 
   # create states
   expect_silent(
-    MarkovState$new(name="Disabled", cost=c.dis)
+    MarkovState$new(name = "Disabled", cost = c.dis)
   )
   expect_silent(
-    MarkovState$new(name="Disabled", utility=u.dis)
+    MarkovState$new(name = "Disabled", utility = u.dis)
   )
 })
 
@@ -59,9 +62,8 @@ test_that("ModVar state utilities whose values exceed 1 cause warnings", {
   expect_silent(
     s.vw <- MarkovState$new(name="Very Well", utility=u.vw)
   )
-  expect_warning(
-    u <- s.vw$utility(),
-    class = "utility_out_of_range"
+  expect_silent(
+    u <- s.vw$utility()
   )
 })
 
@@ -83,4 +85,3 @@ test_that("ModVars are identified and returned", {
   expect_equal(s$cost(), 42)     # mean
   expect_equal(s$utility(), 0.2) # mean
 })
-
