@@ -17,9 +17,9 @@ test_that("stacks of exotic objects are supported", {
   S$push(Node$new("n1"))
   S$push(Node$new("n2"))
   expect_equal(S$size(),2)
-  expect_equal(S$pop()$label(),"n2")
+  expect_identical(S$pop()$label(),"n2")
   expect_equal(S$size(),1)
-  expect_equal(S$pop()$label(),"n1")
+  expect_identical(S$pop()$label(),"n1")
   expect_equal(S$size(),0)
 })
 
@@ -36,11 +36,11 @@ test_that("the stack can be extracted as a list", {
   S$push(4)
   S$push(5)
   S$push(6)
-  expect_equal(S$as_list(), list(3,4,5,6))
+  expect_setequal(S$as_list(), list(3,4,5,6))
   #
   S <- Stack$new()
   S$push(Node$new("n1"))
   S$push(Node$new("n2"))
   L <- S$as_list()
-  expect_equal(L[[2]]$label(), "n2")
+  expect_identical(L[[2]]$label(), "n2")
 })
